<?php
if ( ! class_exists( 'IPChm_Viewer' ))
{
  /**
   * Viewer class
   *
   * @package wp-sales-robot
   * @author QikSoft
   * @link http://qiksoft.com/
   */

  class IPChm_Viewer
  {
    //{{ metabox

    /**
     * Metabox options viewer
     *
     * @return void
     */
    public function metabox( $post )
    {
        $this->post    = $post;
        $this->setting = new IPChm_Setting( $post->ID, '__ipchm-setting' );

        $tab = 'ipchm-section-top-content';
        if ( ! empty( $_REQUEST['tab'] )) {
          $tab = $_REQUEST['tab'];
        }
        $this->tab = $tab;

        //Render view
        $this->view( 'metabox/main' );
    }

    //}}}
    //{{{ content

    /**
     * Upsell content viewer
     *
     * @return string
     */
    public function content()
    {
      global $post;

      $result = '';
      if ( ! empty( $post ))
      {
        $this->post    = $post;
        $this->setting = new IPChm_Setting( $post->ID, '__ipchm-setting' );

        if ( $this->setting->getSetting( 'active', 'false' ) == 'true' )
        {
          //Render view
          ob_start();
          $this->view( 'content/main' );
          $result = ob_get_contents();
          ob_end_clean();
        }
      }
      return $result;
    }

    //}}}
    //{{{ ogcontent

    /**
     * Open graph content viewer
     *
     * @return void
     */
    public function ogcontent()
    {
      global $post;

      $result = '';
      if ( ! empty( $post ))
      {
        $this->post    = $post;
        $this->setting = new IPChm_Setting( $post->ID, '__ipchm-setting' );

        if ( $this->setting->getSetting( 'active', 'false' ) == 'true' )
        {
          $title = $this->setting->getSetting( 'share_title', $post->post_title );
          $desc  = $this->setting->getSetting( 'share_info' );
          if ( ! $desc )
          {
            $content = $post->post_excerpt;
            if ( empty( $content )) {
              $content = $post->post_content;
            }
            $desc = apply_filters( 'get_the_excerpt', $content );
            $desc = apply_filters( 'the_excerpt', $desc );
          }
          $desc  = wp_strip_all_tags( $desc );
          $desc  = wp_trim_words( $desc, 40 );
          $image = '';
          $imgId = $this->setting->getSetting( 'share_image' );
          if ( $imgId )
          {
            $data = wp_get_attachment_image_src( $imgId, 'full' );
            if ( ! empty( $data[0] )) {
              $image = $data[0];
            }
          }
          $url = get_permalink( $post );

          $result .= '<meta property="og:title" content="' . $title . '">';
          $result .= '<meta property="og:description" content="' . $desc . '">';
          $result .= '<meta property="og:type" content="article">';
          $result .= '<meta property="og:image" content="' . $image . '">';
          $result .= '<meta property="og:url" content="' . $url . '">';
        }
      }
      echo $result;
    }

    //}}}
    //{{{ setting

    /**
     * Admin setting viewer
     *
     * @return string
     */
    public function setting()
    {
      $this->pageId = IPCHM_PAGENAME . '-setting';
      //Render view
      $this->view( 'setting/main' );
    }

    //}}}
    //{{{ shortcodeBackend

    /**
     * Shortcode backend viewer
     *
     * @return string
     */
    public function shortcodeBackend()
    {
      $tab = 'ipchm-section-sc-order';
      if ( ! empty( $_REQUEST['tab'] )) {
        $tab = $_REQUEST['tab'];
      }
      $this->tab = $tab;
      //Render view
      $this->view( 'shortcode/backend' );
    }

    //}}}
    //{{{ shortcode

    /**
     * Shortcode viewer
     *
     * @return string
     */
    public function shortcode()
    {
      //Render view
      $this->view( 'shortcode/frontend' );
    }

    //}}
    //{{ view

    /**
     * Get admin view file
     *
     * @param string $filename
     * @return void
     */
    public function view( $filename )
    {
      $path  = IPCHM_VIEW;
      $path .= strtolower( $filename ) . '.php';
      if ( file_exists( $path )) {
        include( $path );
      }
    }

    //}}
    //{{ fix_youtube_url

    /**
     * Fix youtube url
     *
     * @param  string $url
     * @return string
     */
    public function fix_youtube_url( $url )
    {
      if ( $url )
      {
        if ( strpos( $url, 'embed' ) === false )
        {
          if ( strpos( $url, 'watch' ) !== false )
          {
            $id     = '';
            $parsed = parse_url( $url );
            if ( ! empty( $parsed['query'] )) {
                parse_str( $parsed['query'], $args );
                if ( ! empty( $args['v'] )) {
                    $id = $args['v'];
                }
            }
            $url = 'http://youtube.com/embed/' . $id;
          }
          elseif ( strpos( $url, 'youtu.be' ) !== false )
          {
            $id     = '';
            $parsed = parse_url( $url );
            if ( ! empty( $parsed['path'] )) {
                $id = trim( $parsed['path'], '/' );
            }
            $url = 'http://youtube.com/embed/' . $id;
          }
        }
        $url .= '?rel=0';
      }
      return $url;
    }


    //}}
    //{{ getShareLink

    /**
     * Get share link
     *
     * @param  string $type
     * @return string
     */
    public function getShareLink( $type )
    {
      $pagetitle = urlencode( get_the_title() );
      $pageurl   = urlencode( get_permalink() );
      $actions   =  array(
        'facebook'      => 'http://www.facebook.com/share.php?u=' . $pageurl,
        'twitter'       => 'https://twitter.com/share?url=' . $pageurl . '&text=' . $pagetitle,
        'google-plus'   => 'https://plusone.google.com/_/+1/confirm?hl=en&url=' . $pageurl,
        'pinterest'     => 'http://pinterest.com/pin/create/button/?url=' . $pageurl . '&media=&description=' . $pagetitle,
        'linkedin'      => 'http://www.linkedin.com/shareArticle?mini=true&url=' . $pageurl .'&title=' . $pagetitle,
        'tumblr'        => 'http://www.tumblr.com/share?v=3&u=' . $pageurl,
        'stumbleupon'   => 'http://www.stumbleupon.com/submit?url=' . $pageurl . '&title=' . $pagetitle,
        'digg'          => 'http://digg.com/submit?url=' . $pageurl . '&title=' . $pagetitle,
        'email'         => 'mailto:?subject=' . $pagetitle
      );
      $link = '#';
      if ( array_key_exists( $type, $actions )) {
        $link = $actions[$type];
      }
      return $link;
    }

    //}}
    //{{ getGoogleFont

    /**
     * Get Google font
     *
     * @return string
     */
    public function getGoogleFont()
    {
        $fonts   = array();
        $fonts[] = $this->setting->getSetting( 'font_family', 'roboto' );
        $fonts   = array_unique( $fonts );

        $fams  = array();
        $links = IPChm_Font::getLinks();
        foreach( $fonts as $font )
        {
            if ( array_key_exists( $font, $links ))
            {
                $fams[] = $links[$font];
            }
        }

        $family  = implode( '|', $fams );
        $url     = 'http://fonts.googleapis.com/css?family=' . $family;
        return $url;
    }

    //}}
  }
}
